.. nodoctest

Ancillary functions about partial injections
============================================

.. automodule:: stallings_graphs.partial_injections_misc
   :members:
   :undoc-members:
   :show-inheritance:
   

